#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - install script for lm_sensors
#
# Creation:      2005-05-29  Vsevolod Kukol
# Last update:   2024-03-27  Marcus Roeckrath
#
# Copyright: (c) 2005 Vsevolod Kukol
# Copyright: (c) 2009-2013 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
# Copyright: (c) 2016-2024 Marcus Roeckrath, marcus.roeckrath(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=lm_sensors

# change working path
cd /tmp

# ---------------------------------------------------------------------------
# add devices
# ---------------------------------------------------------------------------
idx=0
while [ ${idx} -lt 32 ]
do
    if [ ! -c "/dev/i2c-${idx}" ]
    then
        mknod /dev/i2c-${idx} c 89 ${idx}
    fi
    chown root:root /dev/i2c-${idx}
    chmod 0600 /dev/i2c-${idx}
    idx=$(expr ${idx} + 1)
done

# ---------------------------------------------------------------------------
# add menu
# ---------------------------------------------------------------------------
/var/install/bin/add-menu \
        setup.services.menu \
        setup.services.${package_name}.menu \
        "lm_sensors"

mkdir -p /etc/sysconfig
mkdir -p /etc/sensors.d

# ---------------------------------------------------------------------------
# Create default config
# ---------------------------------------------------------------------------
if [ -f "/etc/config.d/${package_name}" ]
then
    update=true
else
    mkdir -p /var/lib/${package_name}
    echo "datetime" >/var/lib/${package_name}/new-install
fi

/usr/sbin/service daemon-reload

/var/install/config.d/${package_name}-update.sh

# ---------------------------------------------------------------------------
# start configuration
# ---------------------------------------------------------------------------
if ${update:-false}
then
    /var/install/config.d/${package_name}.sh --quiet
    . /etc/config.d/${package_name}
    if [ "${START_LM_SENSORS}" = "yes" ]
    then
        /usr/sbin/service start ${package_name}
    fi
fi

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
