#! /bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/lm_sensors-update.sh - paramater update script
#
# Creation   :  2009-06-21 hbfl
# Last update:  2023-04-07 Marcus Roeckrath
#
# Copyright (c) 2009-2013 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
# Copyright (c) 2013-2023 Marcus Roeckrath, marcus.roeckrath(at)gmx(dot)det
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

#exec 2> /tmp/lm_sensors-update-trace$$.log
#set -x

# set package name
package_name=lm_sensors

# include configlib for using printvar
. /var/install/include/eislib
. /var/install/include/configlib

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
START_LM_SENSORS='no'

LM_SENSORS_CRON_USE='no'
LM_SENSORS_CRON_SCHEDULE='*/5 * * * *'
LM_SENSORS_OUTPUT='/var/log/log.sensors'

LM_SENSORS_ALARM_MAIL='no'
LM_SENSORS_ALARM_MAIL_TO='root@localhost'
LM_SENSORS_ALARM_MAIL_ON_N='1'
LM_SENSORS_ALARM_MAIL_ON_1='CPU-Temp'

LM_SENSORS_ALARM_HALT='no'
LM_SENSORS_ALARM_HALT_ON_N='1'
LM_SENSORS_ALARM_HALT_ON_1='CPU-Temp'
LM_SENSORS_ALARM_HALT_ON_1_LIMIT='70'

LM_SENSORS_I2C_DRIVER_N='1'
LM_SENSORS_I2C_DRIVER_1_NAME='i2c-i801'
LM_SENSORS_I2C_DRIVER_1_ACTIVE='no'

LM_SENSORS_CHIP_N='1'
LM_SENSORS_CHIP_1_NAME=''
LM_SENSORS_CHIP_1_ACTIVE='no'
LM_SENSORS_CHIP_1='via686a'
LM_SENSORS_CHIP_1_BEEP='no'
LM_SENSORS_CHIP_1_LINE_N='29'
LM_SENSORS_CHIP_1_LINE_1='label temp1 "SYS Temp"'
LM_SENSORS_CHIP_1_LINE_2='label temp2 "CPU Temp"'
LM_SENSORS_CHIP_1_LINE_3='label temp3 "SBr Temp"'
LM_SENSORS_CHIP_1_LINE_4='label fan1  "CPU Fan"'
LM_SENSORS_CHIP_1_LINE_5='label fan2  "P/S Fan"'
LM_SENSORS_CHIP_1_LINE_6='label fan3  "P/S Fan2"'
LM_SENSORS_CHIP_1_LINE_7='label "2.0V" "CPU core"'
LM_SENSORS_CHIP_1_LINE_8='label "2.5V" "+2.5V"'
LM_SENSORS_CHIP_1_LINE_9='label "3.3V" "I/O"'
LM_SENSORS_CHIP_1_LINE_10='label "5.0V" "+5V"'
LM_SENSORS_CHIP_1_LINE_11='label "12V" "+12V"'
LM_SENSORS_CHIP_1_LINE_12='set in1_min 2.5 * 0.95'
LM_SENSORS_CHIP_1_LINE_13='set in1_max 2.5 * 1.05'
LM_SENSORS_CHIP_1_LINE_14='set in2_min 3.3 * 0.95'
LM_SENSORS_CHIP_1_LINE_15='set in2_max 3.3 * 1.05'
LM_SENSORS_CHIP_1_LINE_16='set in3_min 5 * 0.9'
LM_SENSORS_CHIP_1_LINE_17='set in3_max 5 * 1.1'
LM_SENSORS_CHIP_1_LINE_18='set in4_min 12 * 0.9'
LM_SENSORS_CHIP_1_LINE_19='set in4_max 12 * 1.1'
LM_SENSORS_CHIP_1_LINE_20='set temp1_hyst 40'
LM_SENSORS_CHIP_1_LINE_21='set temp1_over 45'
LM_SENSORS_CHIP_1_LINE_22='set temp2_hyst 55'
LM_SENSORS_CHIP_1_LINE_23='set temp2_over 60'
LM_SENSORS_CHIP_1_LINE_24='set temp3_hyst 60'
LM_SENSORS_CHIP_1_LINE_25='set temp3_over 65'
LM_SENSORS_CHIP_1_LINE_26='set fan1_min 5000'
LM_SENSORS_CHIP_1_LINE_27='set fan2_min 5000'
LM_SENSORS_CHIP_1_LINE_28='ignore "2.5V"'
LM_SENSORS_CHIP_1_LINE_29='ignore temp3'

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi

    if [ -f /var/run/${package_name}.install ]
    then
        . /var/run/${package_name}.install
        rm /var/run/${package_name}.install
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2009-06-21" "hbfl" "Holger Bruenjes, holgerbruenjes(at)gmx(dot)net"
    # -----------------------------------------------------------------------

    printvar "START_LM_SENSORS"
    printcomment                "Use: yes or no"

    # -----------------------------------------------------------------------
    printgroup "Cron settings"
    # -----------------------------------------------------------------------

    printvar "LM_SENSORS_CRON_USE"
    printcomment                "use cron to request"
    printvar "LM_SENSORS_CRON_SCHEDULE"
    printcomment                "request every 5 minutes"
    printvar "LM_SENSORS_OUTPUT"
    printcomment                "output to using cron"
    printvar "LM_SENSORS_ALARM_MAIL"
    printcomment                "Send Mail on alarm"
    printvar "LM_SENSORS_ALARM_MAIL_TO"
    printcomment                "Mail Adress to send warning to"
    printvar "LM_SENSORS_ALARM_MAIL_ON_N"
    printcomment                "Warn only on specified alarms use '0'"
    printcomment                "for ALL"

    idx=1
    while [ ${idx} -le ${LM_SENSORS_ALARM_MAIL_ON_N} ]
    do
        echo
        printvar "LM_SENSORS_ALARM_MAIL_ON_${idx}"
        printcomment            "CPU-Temp"
        idx=`expr ${idx} + 1`
    done

    echo
    printvar "LM_SENSORS_ALARM_HALT"
    printcomment                "halt system on alarm (!)"
    printvar "LM_SENSORS_ALARM_HALT_ON_N"
    printcomment                "halt only on specified alarms use '0'"
    printcomment                "for all (!)"

    idx=1
    while [ ${idx} -le ${LM_SENSORS_ALARM_HALT_ON_N} ]
    do
        echo
        printvar "LM_SENSORS_ALARM_HALT_ON_${idx}"
        printcomment            "if a label definition is used type the"
        printcomment            "new Label for the value"
        printvar "LM_SENSORS_ALARM_HALT_ON_${idx}_LIMIT"
        printcomment            "limit for '${idx}'. sensor leave empty to use"
        printcomment            "default alarm"
        idx=`expr ${idx} + 1`
    done

    # -----------------------------------------------------------------------
    printgroup "i2c chips "
    # -----------------------------------------------------------------------
    printvar "LM_SENSORS_I2C_DRIVER_N"
    printcomment                "count of driver to configure"

    idx=1
    while [ ${idx} -le ${LM_SENSORS_I2C_DRIVER_N} ]
    do
        printvar "LM_SENSORS_I2C_DRIVER_${idx}_NAME"
        printcomment            "name of the driver to load"
        printvar "LM_SENSORS_I2C_DRIVER_${idx}_ACTIVE"
        printcomment            "Use yes or no"
        idx=`expr ${idx} + 1`
    done

    # -----------------------------------------------------------------------
    printcustomgroup "Chips configuration" <<!EOC
    for a detailed description of this section
    read the documentation, please"
!EOC
    # -----------------------------------------------------------------------
    printvar "LM_SENSORS_CHIP_N"
    printcomment                "count of chips to configure"

    idx=1
    while [ ${idx} -le ${LM_SENSORS_CHIP_N} ]
    do
        printvar "LM_SENSORS_CHIP_${idx}_NAME"
        printcomment            "Is only for you"
        printvar "LM_SENSORS_CHIP_${idx}_ACTIVE"
        printcomment            "Use yes or no"
        printvar "LM_SENSORS_CHIP_${idx}"
        printcomment            "${idx}. name of chip"
        printvar "LM_SENSORS_CHIP_${idx}_BEEP"
        printcomment            "beep for triggered alarms"
        printvar "LM_SENSORS_CHIP_${idx}_LINE_N"
        printcomment            "count of definition lines"

        eval countline='${LM_SENSORS_CHIP_'${idx}'_LINE_N}'
        idx2=1
        while [ ${idx2} -le ${countline} ]
        do
            printvar "LM_SENSORS_CHIP_${idx}_LINE_${idx2}"
            idx2=`expr ${idx2} + 1`
        done
        idx=`expr ${idx} + 1`
    done

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} "2009-06-21" "hbfl" "Holger Bruenjes, holgerbruenjes(at)gmx(dot)net">/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                       OPT_VARIABLE              VARIABLE_N                  VALUE
START_LM_SENSORS                 -                         -                           YESNO

LM_SENSORS_CRON_USE              START_LM_SENSORS          -                           YESNO
LM_SENSORS_CRON_SCHEDULE         LM_SENSORS_CRON_USE       -                           CRONTAB
LM_SENSORS_OUTPUT                LM_SENSORS_CRON_USE       -                           NOTEMPTY
LM_SENSORS_ALARM_MAIL            LM_SENSORS_CRON_USE       -                           YESNO
LM_SENSORS_ALARM_MAIL_TO         LM_SENSORS_ALARM_MAIL     -                           MAILADDR
LM_SENSORS_ALARM_MAIL_ON_N       LM_SENSORS_ALARM_MAIL     -                           NUMERIC
LM_SENSORS_ALARM_MAIL_ON_%       LM_SENSORS_ALARM_MAIL     LM_SENSORS_ALARM_MAIL_ON_N  NOTEMPTY
LM_SENSORS_ALARM_HALT            LM_SENSORS_CRON_USE       -                           YESNO
LM_SENSORS_ALARM_HALT_ON_N       LM_SENSORS_ALARM_HALT     -                           NUMERIC
LM_SENSORS_ALARM_HALT_ON_%       LM_SENSORS_ALARM_HALT     LM_SENSORS_ALARM_HALT_ON_N  NOTEMPTY
LM_SENSORS_ALARM_HALT_ON_%_LIMIT LM_SENSORS_ALARM_HALT     LM_SENSORS_ALARM_HALT_ON_N  ENUMERIC

LM_SENSORS_I2C_DRIVER_N          START_LM_SENSORS          -                           NUMERIC
LM_SENSORS_I2C_DRIVER_%_NAME     START_LM_SENSORS          LM_SENSORS_I2C_DRIVER_N     NONE
LM_SENSORS_I2C_DRIVER_%_ACTIVE   START_LM_SENSORS          LM_SENSORS_I2C_DRIVER_N     YESNO

LM_SENSORS_CHIP_N                START_LM_SENSORS          -                           NUMERIC
LM_SENSORS_CHIP_%_NAME           START_LM_SENSORS          LM_SENSORS_CHIP_N           NONE
LM_SENSORS_CHIP_%_ACTIVE         START_LM_SENSORS          LM_SENSORS_CHIP_N           YESNO
LM_SENSORS_CHIP_%                LM_SENSORS_CHIP_%_ACTIVE  LM_SENSORS_CHIP_N           LM_SENSORS_CHIPS_CUI
LM_SENSORS_CHIP_%_BEEP           LM_SENSORS_CHIP_%_ACTIVE  LM_SENSORS_CHIP_N           LM_SENSORS_BEEP
LM_SENSORS_CHIP_%_LINE_N         LM_SENSORS_CHIP_%_ACTIVE  LM_SENSORS_CHIP_N           NUMERIC
LM_SENSORS_CHIP_%_LINE_%         LM_SENSORS_CHIP_%_ACTIVE  LM_SENSORS_CHIP_%_LINE_N    LM_SENSORS_CONFITEM
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}
   cp /etc/check.d/${package_name} /usr/share/doc/lm_sensors/${package_name}.namecheck
   sed s/LM_SENSORS_CHIPS_CUI/NONE/g /etc/check.d/${package_name} > /usr/share/doc/lm_sensors/${package_name}.nonamecheck
   chmod 0600 /usr/share/doc/lm_sensors/${package_name}.namecheck
   chmod 0600 /usr/share/doc/lm_sensors/${package_name}.nonamecheck
   chown root:root /usr/share/doc/lm_sensors/${package_name}.namecheck
   chown root:root /usr/share/doc/lm_sensors/${package_name}.nonamecheck

cat >/var/install/bin/pre-setup-services-lm_sensors-edit <<EOFG
#!/bin/sh
#--------------------------------------------------------------------
#  edit file generated by ${package_name} version: ${VERSION}
#
#  Do not edit this file, it was auto created
#  Creation Date: ${EISDATE} Time: ${EISTIME}
#--------------------------------------------------------------------


# include eislib
. /var/install/include/eislib

new_install="/var/lib/${package_name}/new-install"

if [ -f \${new_install} ]
then
    echo
    mecho --error "Please run the (Re)detect Hardware menu entry first."
    echo
    # musst by exit code 2
    # to handle in show-menu correct
    exit 2
fi

get_chips ()
{
    mod_list="/etc/sysconfig/lm_sensors"
    map_list="/usr/share/doc/lm_sensors/modules2chips.txt"

    if [ -f "\${mod_list}" ]
    then
        . "\${mod_list}"
        for modul in \${HWMON_MODULES}
        do
            modul=\$(grep "\${modul}:" "\${map_list}" | cut -d ":" -f 2)

            if [ -z "\${module_list}" ]
            then
                module_list="\${modul}"
                module_list_dialog="\${modul}"
            else
                module_list="\${module_list}|"\${modul}
                module_list_dialog="\${module_list_dialog},"\${modul}
            fi
        done

        module_list=\$(echo "\${module_list}" | sed s/,/\|/g)

    fi

    sed -i "s#sellist=.*#sellist='\${module_list_dialog}'#" \\
        /var/install/dialog.d/LM_SENSORS_CHIPS_CUI.sh
}
get_chips



. /var/install/include/configlib

printgpl --check_exp ${package_name} "2009-06-21" "hbfl" "Holger Bruenjes, holgerbruenjes(at)gmx(dot)net" >/etc/check.d/${package_name}.exp
cat >>/etc/check.d/${package_name}.exp <<EOF
LM_SENSORS_BEEP      = 'yes|no|none'
                     : 'Wrong keyword. Following keywords are allowed:
            yes, no, none.'
LM_SENSORS_CONFITEM  = '^chip.+|^label.+|^compute.+|^set.+|^ignore.+'
                     : 'Wrong keyword for sensors3.conf. Following keywords are allowed:
            chip, label, compute, set, ignore.'
LM_SENSORS_CHIPS_CUI = '\${module_list}'
                     : 'Use one of \${module_list_dialog}'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp
EOFG

    chmod 0755 /var/install/bin/pre-setup-services-lm_sensors-edit
}
# ---------------------------------------------------------------------------
# Main
# ---------------------------------------------------------------------------
# write default config file

make_config_file /etc/default.d/${package_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${package_name}

# write check.d file
make_check_file


exit 0
# ---------------------------------------------------------------------------
# End
# ---------------------------------------------------------------------------
